@@ -45,7 +45,7 @@ class Page:
 class HomePage(Page):
     """A class to handle a homepage to be rendered"""
 
-    html_template = "index.html"
+    html_template = "index.html.j2"
     html = "index.html"
     name = 'home'
     parent = None
@@ -80,6 +80,18 @@ class HomePage(Page):
     def _get_variables(self):
         """Set some variables from conf dictionnary and notebooks files"""
 
+        def build_link_name(link_type: str, suffix: str):
+            """Build archive or pdf book links from slug name"""
+            if link_type in self.variables['links']:
+                try:
+                    # For example look for yaml entry: `book: file: filename.pdf`
+                    self.variables['links'][link_type]['target'] = \
+                        self.variables[link_type]['file']
+                except KeyError:
+                    # Use <slug_title>.pdf
+                    self.variables['links'][link_type]['target'] = \
+                        self.variables['slug_title'] + suffix
+
         # Get chapters from notebook files
         chapters = []
         for nbfile in self.notebooks:
@@ -92,6 +104,9 @@ class HomePage(Page):
             chapters.append(chapter)
         chapters.sort(key=lambda chapter: chapter['number'])
         self.variables.update({'chapters': chapters})
+        build_link_name('book', '.pdf')
+        build_link_name('archive', '.zip')
+
         log.debug("Homepage template variables:")
         log.debug(pformat(self.variables))
 
@@ -114,7 +129,7 @@ class HomePage(Page):
 
 class MarkdownPage(Page):
 
-    html_template = "page.html"
+    html_template = "page.html.j2"
 
     def __init__(self, nbcourse, src: Path):
         super().__init__(nbcourse)
